@@ -39,8 +39,11 @@ def check_readiness(url: str, retries=5):
     try_ = 0
     _url = url if url.startswith("https://") else f"https://{url}"
     while code != 200 or try_ >= retries:
-        res = requests.get(_url)
-        code = res.status_code
+        try:
+            res = requests.get(_url)
+            code = res.status_code
+        except Exception:
+            code = -1
         if code != 200:
             time.sleep(10)
         try_ += 1
@@ -352,6 +355,21 @@ def volume_import(state, name):
     console.print(f"Volume {name} imported.")
 
 
+@volumes.command(name="unlink")
+@click.option("--state", "-s", default=None,
+              help="Where state will be stored")
+@click.option("--name", "-n", required=True,
+              help="Name of the volume")
+def volume_unlink(state, name):
+    """ unlink a volume from this project """
+    _state = state if state else load_state()
+    jup = JupyterController.from_state(_state)
+    if jup._state.volumes.get(name):
+        del(jup._state.volumes[name])
+        jup.push()
+        console.print(f"Volume {name} unlinked.")
+
+
 @volumes.command(name="resize")
 @click.option("--state", "-s", default=None,
               help="Where state will be stored")
